@@ -25,11 +25,11 @@ class PolynomialLibrary(PolynomialFeatures, BaseFeatureLibrary):
         The degree of the polynomial features.
     include_interaction : boolean, optional (default True)
         Determines whether interaction features are produced.
-        If false, features are all of the form `x[i] ** k`.
+        If false, features are all of the form ``x[i] ** k``.
     interaction_only : boolean, optional (default False)
         If true, only interaction features are produced: features that are
-        products of at most `degree` *distinct* input features (so not
-        `x[1] ** 2`, `x[0] * x[2] ** 3`, etc.).
+        products of at most ``degree`` *distinct* input features (so not
+        ``x[1] ** 2``, ``x[0] * x[2] ** 3``, etc.).
     include_bias : boolean, optional (default True)
         If True (default), then include a bias column, the feature in which
         all polynomial powers are zero (i.e. a column of ones - acts as an
@@ -42,6 +42,13 @@ class PolynomialLibrary(PolynomialFeatures, BaseFeatureLibrary):
     ----------
     powers_ : array, shape (n_output_features, n_input_features)
         powers_[i, j] is the exponent of the jth input in the ith output.
+
+    n_input_features_ : int
+        The total number of input features.
+
+    n_output_features_ : int
+        The total number of output features. This number is computed by
+        iterating over all appropriately sized combinations of input features.
     """
 
     def __init__(
