@@ -17,8 +17,8 @@ class SR3(BaseOptimizer):
 
     .. math::
 
-        0.5\\|y-Xw\\|^2_2 + lambda \\times R(v)
-        + (0.5 / nu)\\|w-v\\|^2_2
+        0.5\\|y-Xw\\|^2_2 + \\lambda \\times R(v)
+        + (0.5 / \\nu)\\|w-v\\|^2_2
 
     where :math:`R(v)` is a regularization function. See the following reference
     for more details:
@@ -74,6 +74,11 @@ class SR3(BaseOptimizer):
         Weight vector(s) that are not subjected to the regularization.
         This is the w in the objective function.
 
+    history_ : list
+        History of sparse coefficients. ``history_[k]`` contains the
+        sparse coefficients (v in the optimization objective function)
+        at iteration k.
+
     Examples
     --------
     >>> import numpy as np
