@@ -9,11 +9,10 @@ from pysindy.optimizers import BaseOptimizer
 
 
 class STLSQ(BaseOptimizer):
-    """
-    Sequentially thresholded least squares algorithm.
+    """Sequentially thresholded least squares algorithm.
 
     Attempts to minimize the objective function
-    :math:`\\|y - Xw\\|^2_2 + alpha \\times \\|w\\|^2_2`
+    :math:`\\|y - Xw\\|^2_2 + \\alpha \\|w\\|^2_2`
     by iteratively performing least squares and masking out
     elements of the weight that are below a given threshold.
 
@@ -24,7 +23,7 @@ class STLSQ(BaseOptimizer):
         Coefficients with magnitude below the threshold are set
         to zero.
 
-    alpha : float, optional (default 0.1)
+    alpha : float, optional (default 0.05)
         Optional L2 (ridge) regularization on the weight vector.
 
     max_iter : int, optional (default 20)
@@ -48,12 +47,16 @@ class STLSQ(BaseOptimizer):
     Attributes
     ----------
     coef_ : array, shape (n_features,) or (n_targets, n_features)
-        Weight vector(s)
+        Weight vector(s).
 
     ind_ : array, shape (n_features,) or (n_targets, n_features)
         Array of 0s and 1s indicating which coefficients of the
         weight vector have not been masked out.
 
+    history_ : list
+        History of ``coef_``. ``history_[k]`` contains the values of
+        ``coef_`` at iteration k of sequentially thresholded least-squares.
+
     Examples
     --------
     >>> import numpy as np
@@ -77,7 +80,7 @@ class STLSQ(BaseOptimizer):
     def __init__(
         self,
         threshold=0.1,
-        alpha=0.1,
+        alpha=0.05,
         max_iter=20,
         ridge_kw=None,
         normalize=False,
@@ -128,8 +131,7 @@ class STLSQ(BaseOptimizer):
         return all(bool(i) == bool(j) for i, j in zip(this_coef, last_coef))
 
     def _reduce(self, x, y):
-        """
-        Iterates the thresholding. Assumes an initial guess is saved in
+        """Iterates the thresholding. Assumes an initial guess is saved in
         self.coef_ and self.ind_
         """
         ind = self.ind_
@@ -140,10 +142,8 @@ class STLSQ(BaseOptimizer):
         for _ in range(self.max_iter):
             if np.count_nonzero(ind) == 0:
                 warnings.warn(
-                    """Sparsity parameter is too big ({}) and eliminated all
-                    coefficients""".format(
-                        self.threshold
-                    )
+                    "Sparsity parameter is too big ({}) and eliminated all "
+                    "coefficients".format(self.threshold)
                 )
                 coef = np.zeros((n_targets, n_features))
                 break
@@ -152,10 +152,8 @@ class STLSQ(BaseOptimizer):
             for i in range(n_targets):
                 if np.count_nonzero(ind[i]) == 0:
                     warnings.warn(
-                        """Sparsity parameter is too big ({}) and eliminated all
-                        coefficients""".format(
-                            self.threshold
-                        )
+                        "Sparsity parameter is too big ({}) and eliminated all "
+                        "coefficients".format(self.threshold)
                     )
                     continue
                 coef_i = self._regress(x[:, ind[i]], y[:, i])
